@@ -1,15 +1,15 @@
 /*! \file
 Copyright (c) 2003, The Regents of the University of California, through
-Lawrence Berkeley National Laboratory (subject to receipt of any required 
-approvals from U.S. Dept. of Energy) 
+Lawrence Berkeley National Laboratory (subject to receipt of any required
+approvals from U.S. Dept. of Energy)
 
-All rights reserved. 
+All rights reserved.
 
 The source code is distributed under BSD license, see the file License.txt
 at the top-level directory.
 */
 
-/*! @file 
+/*! @file
  * \brief Solves a system of linear equations A*X=B,
  *
  * <pre>
@@ -49,7 +49,7 @@ at the top-level directory.
  *      -  B, the matrix of right hand sides, and its dimensions ldb and nrhs
  *      -  grid, a structure describing the 2D processor mesh
  *      -  options->IterRefine, which determines whether or not to
- *            improve the accuracy of the computed solution using 
+ *            improve the accuracy of the computed solution using
  *            iterative refinement
  *
  *      On output, B is overwritten with the solution X.
@@ -57,8 +57,8 @@ at the top-level directory.
  *   2. Depending on options->Fact, the user has several options
  *      for solving A*X=B. The standard option is for factoring
  *      A "from scratch". (The other options, described below,
- *      are used when A is sufficiently similar to a previously 
- *      solved problem to save time by reusing part or all of 
+ *      are used when A is sufficiently similar to a previously
+ *      solved problem to save time by reusing part or all of
  *      the previous factorization.)
  *
  *      -  options->Fact = DOFACT: A is factored "from scratch"
@@ -67,7 +67,7 @@ at the top-level directory.
  *
  *      -  A, the input matrix
  *
- *      as well as the following options, which are described in more 
+ *      as well as the following options, which are described in more
  *      detail below:
  *
  *      -  options->Equil,   to specify how to scale the rows and columns
@@ -87,7 +87,7 @@ at the top-level directory.
  *                           (to control numerical stability)
  *
  *      The outputs returned include
- *         
+ *
  *      -  ScalePermstruct,  modified to describe how the input matrix A
  *                           was equilibrated and permuted:
  *         -  ScalePermstruct->DiagScale, indicates whether the rows and/or
@@ -98,17 +98,17 @@ at the top-level directory.
  *         -  ScalePermstruct->perm_c, column permutation vector
  *
  *            (part of ScalePermstruct may also need to be supplied on input,
- *             depending on options->RowPerm and options->ColPerm as described 
+ *             depending on options->RowPerm and options->ColPerm as described
  *             later).
  *
  *      -  A, the input matrix A overwritten by the scaled and permuted matrix
  *                Pc*Pr*diag(R)*A*diag(C)
- *             where 
+ *             where
  *                Pr and Pc are row and columns permutation matrices determined
- *                  by ScalePermstruct->perm_r and ScalePermstruct->perm_c, 
- *                  respectively, and 
+ *                  by ScalePermstruct->perm_r and ScalePermstruct->perm_c,
+ *                  respectively, and
  *                diag(R) and diag(C) are diagonal scaling matrices determined
- *                  by ScalePermstruct->DiagScale, ScalePermstruct->R and 
+ *                  by ScalePermstruct->DiagScale, ScalePermstruct->R and
  *                  ScalePermstruct->C
  *
  *      -  LUstruct, which contains the L and U factorization of A1 where
@@ -120,7 +120,7 @@ at the top-level directory.
  *
  *   3. The second value of options->Fact assumes that a matrix with the same
  *      sparsity pattern as A has already been factored:
- *     
+ *
  *      -  options->Fact = SamePattern: A is factored, assuming that it has
  *            the same nonzero pattern as a previously factored matrix. In this
  *            case the algorithm saves time by reusing the previously computed
@@ -136,14 +136,14 @@ at the top-level directory.
  *
  *      but not options->ColPerm, whose value is ignored. This is because the
  *      previous column permutation from ScalePermstruct->perm_c is used as
- *      input. The user must also supply 
+ *      input. The user must also supply
  *
  *      -  A, the input matrix
  *      -  ScalePermstruct->perm_c, the column permutation
  *      -  LUstruct->etree, the elimination tree
  *
  *      The outputs returned include
- *         
+ *
  *      -  A, the input matrix A overwritten by the scaled and permuted matrix
  *            as described above
  *      -  ScalePermstruct,  modified to describe how the input matrix A was
@@ -171,32 +171,32 @@ at the top-level directory.
  *      This is because the permutations from ScalePermstruct->perm_r and
  *      ScalePermstruct->perm_c are used as input.
  *
- *      The user must also supply 
+ *      The user must also supply
  *
  *      -  A, the input matrix
  *      -  ScalePermstruct->DiagScale, how the previous matrix was row and/or
  *                                     column scaled
  *      -  ScalePermstruct->R, the row scalings of the previous matrix, if any
- *      -  ScalePermstruct->C, the columns scalings of the previous matrix, 
+ *      -  ScalePermstruct->C, the columns scalings of the previous matrix,
  *                             if any
  *      -  ScalePermstruct->perm_r, the row permutation of the previous matrix
- *      -  ScalePermstruct->perm_c, the column permutation of the previous 
+ *      -  ScalePermstruct->perm_c, the column permutation of the previous
  *                                  matrix
  *      -  all of LUstruct, the previously computed information about L and U
  *                (the actual numerical values of L and U stored in
  *                 LUstruct->Llu are ignored)
  *
  *      The outputs returned include
- *         
+ *
  *      -  A, the input matrix A overwritten by the scaled and permuted matrix
  *            as described above
  *      -  ScalePermstruct,  modified to describe how the input matrix A was
- *                           equilibrated 
+ *                           equilibrated
  *                  (thus ScalePermstruct->DiagScale, R and C may be modified)
  *      -  LUstruct, modified to contain the new L and U factors
  *
  *   5. The fourth and last value of options->Fact assumes that A is
- *      identical to a matrix that has already been factored on a previous 
+ *      identical to a matrix that has already been factored on a previous
  *      call, and reuses its entire LU factorization
  *
  *      -  options->Fact = Factored: A is identical to a previously
@@ -204,19 +204,19 @@ at the top-level directory.
  *            can be reused.
  *
  *      In this case all the other options mentioned above are ignored
- *      (options->Equil, options->RowPerm, options->ColPerm, 
+ *      (options->Equil, options->RowPerm, options->ColPerm,
  *       options->ReplaceTinyPivot)
  *
- *      The user must also supply 
+ *      The user must also supply
  *
  *      -  A, the unfactored matrix, only in the case that iterative refinement
- *            is to be done (specifically A must be the output A from 
+ *            is to be done (specifically A must be the output A from
  *            the previous call, so that it has been scaled and permuted)
  *      -  all of ScalePermstruct
  *      -  all of LUstruct, including the actual numerical values of L and U
  *
  *      all of which are unmodified on output.
- *         
+ *
  * Arguments
  * =========
  *
@@ -224,7 +224,7 @@ at the top-level directory.
  *         The structure defines the input parameters to control
  *         how the LU decomposition will be performed.
  *         The following fields should be defined for this structure:
- *         
+ *
  *         o Fact (fact_t)
  *           Specifies whether or not the factored form of the matrix
  *           A is supplied on entry, and if not, how the matrix A should
@@ -234,7 +234,7 @@ at the top-level directory.
  *                 Inputs:  A
  *                          options->Equil, RowPerm, ColPerm, ReplaceTinyPivot
  *                 Outputs: modified A
- *                             (possibly row and/or column scaled and/or 
+ *                             (possibly row and/or column scaled and/or
  *                              permuted)
  *                          all of ScalePermstruct
  *                          all of LUstruct
@@ -242,7 +242,7 @@ at the top-level directory.
  *           = SamePattern: the matrix A will be factorized assuming
  *             that a factorization of a matrix with the same sparsity
  *             pattern was performed prior to this one. Therefore, this
- *             factorization will reuse column permutation vector 
+ *             factorization will reuse column permutation vector
  *             ScalePermstruct->perm_c and the elimination tree
  *             LUstruct->etree
  *                 Inputs:  A
@@ -250,7 +250,7 @@ at the top-level directory.
  *                          ScalePermstruct->perm_c
  *                          LUstruct->etree
  *                 Outputs: modified A
- *                             (possibly row and/or column scaled and/or 
+ *                             (possibly row and/or column scaled and/or
  *                              permuted)
  *                          rest of ScalePermstruct (DiagScale, R, C, perm_r)
  *                          rest of LUstruct (GLU_persist, Llu)
@@ -268,7 +268,7 @@ at the top-level directory.
  *                          all of ScalePermstruct
  *                          all of LUstruct
  *                 Outputs: modified A
- *                             (possibly row and/or column scaled and/or 
+ *                             (possibly row and/or column scaled and/or
  *                              permuted)
  *                          modified LUstruct->Llu
  *           = FACTORED: the matrix A is already factored.
@@ -297,17 +297,17 @@ at the top-level directory.
  *                        off-diagonal.
  *           = MY_PERMR:  use the ordering given in ScalePermstruct->perm_r
  *                        input by the user.
- *           
+ *
  *         o ColPerm (colperm_t)
  *           Specifies what type of column permutation to use to reduce fill.
  *           = NATURAL:       natural ordering.
  *           = MMD_AT_PLUS_A: minimum degree ordering on structure of A'+A.
  *           = MMD_ATA:       minimum degree ordering on structure of A'*A.
  *           = MY_PERMC:      the ordering given in ScalePermstruct->perm_c.
- *         
+ *
  *         o ReplaceTinyPivot (yes_no_t)
  *           = NO:  do not modify pivots
- *           = YES: replace tiny pivots by sqrt(epsilon)*norm(A) during 
+ *           = YES: replace tiny pivots by sqrt(epsilon)*norm(A) during
  *                  LU factorization.
  *
  *         o IterRefine (IterRefine_t)
@@ -342,7 +342,7 @@ at the top-level directory.
  *         NOTE: Currently, A must reside in all processes when calling
  *               this routine.
  *
- * ScalePermstruct (input/output) ScalePermstruct_t*
+ * ScalePermstruct (input/output) zScalePermstruct_t*
  *         The data structure to store the scaling and permutation vectors
  *         describing the transformations performed to the matrix A.
  *         It contains the following fields:
@@ -354,7 +354,7 @@ at the top-level directory.
  *                      diag(R).
  *           = COL:     Column equilibration, i.e., A was postmultiplied
  *                      by diag(C).
- *           = BOTH:    both row and column equilibration, i.e., A was 
+ *           = BOTH:    both row and column equilibration, i.e., A was
  *                      replaced by diag(R)*A*diag(C).
  *           If options->Fact = FACTORED or SamePattern_SameRowPerm,
  *           DiagScale is an input argument; otherwise it is an output
@@ -368,8 +368,8 @@ at the top-level directory.
  *           input argument; otherwise it is an output argument.
  *
  *         o perm_c (int*)
- *           Column permutation vector, which defines the 
- *           permutation matrix Pc; perm_c[i] = j means column i of A is 
+ *           Column permutation vector, which defines the
+ *           permutation matrix Pc; perm_c[i] = j means column i of A is
  *           in position j in A*Pc.
  *           If options->ColPerm = MY_PERMC or options->Fact = SamePattern
  *           or options->Fact = SamePattern_SameRowPerm, perm_c is an
@@ -381,7 +381,7 @@ at the top-level directory.
  *
  *         o R (double*) dimension (A->nrow)
  *           The row scale factors for A.
- *           If DiagScale = ROW or BOTH, A is multiplied on the left by 
+ *           If DiagScale = ROW or BOTH, A is multiplied on the left by
  *                          diag(R).
  *           If DiagScale = NOEQUIL or COL, R is not defined.
  *           If options->Fact = FACTORED or SamePattern_SameRowPerm, R is
@@ -389,12 +389,12 @@ at the top-level directory.
  *
  *         o C (double*) dimension (A->ncol)
  *           The column scale factors for A.
- *           If DiagScale = COL or BOTH, A is multiplied on the right by 
+ *           If DiagScale = COL or BOTH, A is multiplied on the right by
  *                          diag(C).
  *           If DiagScale = NOEQUIL or ROW, C is not defined.
  *           If options->Fact = FACTORED or SamePattern_SameRowPerm, C is
  *           an input argument; otherwise, C is an output argument.
- *         
+ *
  * B       (input/output) doublecomplex*
  *         On entry, the right-hand side matrix of dimension (A->nrow, nrhs).
  *         On exit, the solution matrix if info = 0;
@@ -418,7 +418,7 @@ at the top-level directory.
  *         Grid can be initialized by subroutine SUPERLU_GRIDINIT.
  *         See superlu_zdefs.h for the definition of 'gridinfo_t'.
  *
- * LUstruct (input/output) LUstruct_t*
+ * LUstruct (input/output) zLUstruct_t*
  *         The data structures to store the distributed L and U factors.
  *         It contains the following fields:
  *
@@ -441,13 +441,13 @@ at the top-level directory.
  *	       xsup[s] is the leading column of the s-th supernode,
  *             supno[i] is the supernode number to which column i belongs.
  *
- *         o Llu (LocalLU_t*)
+ *         o Llu (zLocalLU_t*)
  *           The distributed data structures to store L and U factors.
- *           See superlu_ddefs.h for the definition of 'LocalLU_t'.
+ *           See superlu_ddefs.h for the definition of 'zLocalLU_t'.
  *
  * berr    (output) double*, dimension (nrhs)
- *         The componentwise relative backward error of each solution   
- *         vector X(j) (i.e., the smallest relative change in   
+ *         The componentwise relative backward error of each solution
+ *         vector X(j) (i.e., the smallest relative change in
  *         any element of A or B that makes X(j) an exact solution).
  *
  * stat   (output) SuperLUStat_t*
@@ -468,10 +468,10 @@ at the top-level directory.
  * </pre>
  */
 void
-pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A, 
-		 ScalePermstruct_t *ScalePermstruct,
+pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
+		 zScalePermstruct_t *ScalePermstruct,
 		 doublecomplex B[], int ldb, int nrhs, gridinfo_t *grid,
-		 LUstruct_t *LUstruct, double *berr,
+		 zLUstruct_t *LUstruct, double *berr,
 		 SuperLUStat_t *stat, int *info)
 {
     SuperMatrix AC;
@@ -485,7 +485,7 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 		                 supernodes in L.
           	   (usub, xusub) contains the compressed subscript of
 		                 nonzero segments in U.
-	      If options->Fact != SamePattern_SameRowPerm, they are 
+	      If options->Fact != SamePattern_SameRowPerm, they are
 	      computed by SYMBFACT routine, and then used by DDISTRIBUTE
 	      routine. They will be freed after DDISTRIBUTE routine.
 	      If options->Fact == SamePattern_SameRowPerm, these
@@ -577,12 +577,12 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 		ScalePermstruct->R = R;
 		ScalePermstruct->C = C;
 		break;
-	    case ROW: 
+	    case ROW:
 	        if ( !(C = (double *) doubleMalloc_dist(n)) )
 		    ABORT("Malloc fails for C[].");
 		ScalePermstruct->C = C;
 		break;
-	    case COL: 
+	    case COL:
 		if ( !(R = (double *) doubleMalloc_dist(m)) )
 		    ABORT("Malloc fails for R[].");
 		ScalePermstruct->R = R;
@@ -617,7 +617,7 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 		    for (i = colptr[j]; i < colptr[j+1]; ++i)
 			zd_mult(&a[i], &a[i], C[j]); /* Scale columns. */
 		break;
-	      case BOTH: 
+	      case BOTH:
 		for (j = 0; j < n; ++j) {
 		    for (i = colptr[j]; i < colptr[j+1]; ++i) {
 			irow = rowind[i];
@@ -631,7 +631,7 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 	    if ( !iam ) {
 		/* Compute row and column scalings to equilibrate matrix A. */
 		zgsequ_dist(A, R, C, &rowcnd, &colcnd, &amax, &iinfo);
-	    
+
 		MPI_Bcast( &iinfo, 1, mpi_int_t, 0, grid->comm );
 		if ( iinfo == 0 ) {
 		    MPI_Bcast( R,       m, MPI_DOUBLE, 0, grid->comm );
@@ -643,12 +643,12 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 		    if ( iinfo > 0 ) {
 			if ( iinfo <= m ) {
 #if ( PRNTlevel>=1 )
-			    fprintf(stderr, "The " IFMT "-th row of A is exactly zero\n", 
+			    fprintf(stderr, "The " IFMT "-th row of A is exactly zero\n",
 				    iinfo);
 #endif
 			} else {
 #if ( PRNTlevel>=1 )
-                            fprintf(stderr, "The " IFMT "-th column of A is exactly zero\n", 
+                            fprintf(stderr, "The " IFMT "-th column of A is exactly zero\n",
 				     iinfo-n);
 #endif
                         }
@@ -662,9 +662,9 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 		    MPI_Bcast( &rowcnd, 1, MPI_DOUBLE, 0, grid->comm );
 		    MPI_Bcast( &colcnd, 1, MPI_DOUBLE, 0, grid->comm );
 		    MPI_Bcast( &amax,   1, MPI_DOUBLE, 0, grid->comm );
-		} 
+		}
 	    }
-	
+
             if ( iinfo == 0 ) {
 	        /* Equilibrate matrix A. */
 	        zlaqgs_dist(A, R, C, rowcnd, colcnd, amax, equed);
@@ -694,9 +694,9 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 	CHECK_MALLOC(iam, "Exit equil");
 #endif
     } /* end if Equil ... */
-    
+
     /* ------------------------------------------------------------
-       Permute rows of A. 
+       Permute rows of A.
        ------------------------------------------------------------*/
     if ( options->RowPerm != NO ) {
 	t = SuperLU_timer_();
@@ -712,7 +712,7 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 	} else if ( !factored ) {
 	    if ( job == 5 ) {
 		/* Allocate storage for scaling factors. */
-		if ( !(R1 = (double *) SUPERLU_MALLOC(m * sizeof(double))) ) 
+		if ( !(R1 = (double *) SUPERLU_MALLOC(m * sizeof(double))) )
 		    ABORT("SUPERLU_MALLOC fails for R1[]");
 		if ( !(C1 = (double *) SUPERLU_MALLOC(n * sizeof(double))) )
 		    ABORT("SUPERLU_MALLOC fails for C1[]");
@@ -723,7 +723,7 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 		iinfo = zldperm_dist(job, m, nnz, colptr, rowind, a,
                                 perm_r, R1, C1);
 
-                MPI_Bcast( &iinfo, 1, mpi_int_t, 0, grid->comm );		
+                MPI_Bcast( &iinfo, 1, mpi_int_t, 0, grid->comm );
 		if ( iinfo == 0 ) {
 		    MPI_Bcast( perm_r, m, mpi_int_t, 0, grid->comm );
 		    if ( job == 5 && Equil ) {
@@ -777,7 +777,7 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 		    else for (i = 0; i < m; ++i) R[i] = R1[i];
 		    if ( colequ ) for (i = 0; i < n; ++i) C[i] *= C1[i];
 		    else for (i = 0; i < n; ++i) C[i] = C1[i];
-		    
+
 		    ScalePermstruct->DiagScale = BOTH;
 		    rowequ = colequ = 1;
 		} else { /* No equilibration. */
@@ -821,12 +821,12 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 		if ( !iam ) printf("\t product of diagonal %e\n", dprod);
 	    }
 #endif
-	    
+
         } /* else !factored */
 
 	t = SuperLU_timer_() - t;
 	stat->utime[ROWPERM] = t;
-    
+
     } else { /* options->RowPerm == NOROWPERM */
         for (i = 0; i < m; ++i) perm_r[i] = i;
     }
@@ -845,7 +845,7 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 	t = SuperLU_timer_();
 	/*
 	 * Get column permutation vector perm_c[], according to permc_spec:
-	 *   permc_spec = NATURAL:  natural ordering 
+	 *   permc_spec = NATURAL:  natural ordering
 	 *   permc_spec = MMD_AT_PLUS_A: minimum degree on structure of A'+A
 	 *   permc_spec = MMD_ATA:  minimum degree on structure of A'*A
 	 *   permc_spec = MY_PERMC: the ordering already supplied in perm_c[]
@@ -863,7 +863,7 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 
 	/* Form Pc*A*Pc' to preserve the diagonal of the matrix Pr*A. */
 	ACstore = AC.Store;
-	for (j = 0; j < n; ++j) 
+	for (j = 0; j < n; ++j)
 	    for (i = ACstore->colbeg[j]; i < ACstore->colend[j]; ++i) {
 		irow = ACstore->rowind[i];
 		ACstore->rowind[i] = perm_c[irow];
@@ -873,8 +873,8 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 	/* Perform a symbolic factorization on matrix A and set up the
 	   nonzero data structures which are suitable for supernodal GENP. */
 	if ( Fact != SamePattern_SameRowPerm ) {
-#if ( PRNTlevel>=1 ) 
-	    if ( !iam ) 
+#if ( PRNTlevel>=1 )
+	    if ( !iam )
 		printf(".. symbfact(): relax " IFMT ", maxsuper " IFMT ", fill " IFMT "\n",
 		       sp_ienv_dist(2), sp_ienv_dist(3), sp_ienv_dist(6));
 #endif
@@ -883,23 +883,23 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 		   SUPERLU_MALLOC(sizeof(Glu_freeable_t))) )
 		ABORT("Malloc fails for Glu_freeable.");
 
-	    iinfo = symbfact(options, iam, &AC, perm_c, etree, 
+	    iinfo = symbfact(options, iam, &AC, perm_c, etree,
 			     Glu_persist, Glu_freeable);
 
 	    stat->utime[SYMBFAC] = SuperLU_timer_() - t;
 
 	    if ( iinfo <= 0 ) {
 		QuerySpace_dist(n, -iinfo, Glu_freeable, &symb_mem_usage);
-#if ( PRNTlevel>=1 ) 
+#if ( PRNTlevel>=1 )
 		if ( !iam ) {
 		    printf("\tNo of supers " IFMT "\n", Glu_persist->supno[n-1]+1);
 		    printf("\tSize of G(L) " IFMT "\n", Glu_freeable->xlsub[n]);
 		    printf("\tSize of G(U) " IFMT "\n", Glu_freeable->xusub[n]);
-		    printf("\tint %d, short %d, float %d, double %d\n", 
-			   (int) sizeof(int_t), (int) sizeof(short), 
+		    printf("\tint %d, short %d, float %d, double %d\n",
+			   (int) sizeof(int_t), (int) sizeof(short),
  			   (int) sizeof(float), (int) sizeof(double));
 		    printf("\tSYMBfact (MB):\tL\\U %.2f\ttotal %.2f\texpansions " IFMT "\n",
-			   symb_mem_usage.for_lu*1e-6, 
+			   symb_mem_usage.for_lu*1e-6,
 			   symb_mem_usage.total*1e-6,
 			   symb_mem_usage.expansions);
 		}
@@ -909,7 +909,7 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 		if ( !iam )
 		    fprintf(stderr, "symbfact() error returns " IFMT "\n", iinfo);
 #endif
-                *info = iinfo;  
+                *info = iinfo;
                 return;
 	    }
 	}
@@ -961,14 +961,14 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 	    }
 	}
 #endif
-    
+
     } else if ( options->IterRefine ) { /* options->Fact==FACTORED */
 	/* Permute columns of A to form A*Pc' using the existing perm_c.
 	 * NOTE: rows of A were previously permuted to Pc*A.
 	 */
 	sp_colorder(options, A, perm_c, NULL, &AC);
     } /* if !factored ... */
-	
+
     /* ------------------------------------------------------------
        Compute the solution matrix X.
        ------------------------------------------------------------*/
@@ -978,7 +978,7 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 	    ABORT("Malloc fails for b_work[]");
 
 	/* ------------------------------------------------------------
-	   Scale the right-hand side if equilibration was performed. 
+	   Scale the right-hand side if equilibration was performed.
 	   ------------------------------------------------------------*/
 	if ( notran ) {
 	    if ( rowequ ) {
@@ -1056,7 +1056,7 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 	    x_col = &X[j*ldx];
 	    for (i = 0; i < n; ++i) b_col[i] = x_col[perm_c[i]];
 	}
-	
+
 	/* Transform the solution matrix X to a solution of the original system
 	   before the equilibration. */
 	if ( notran ) {
@@ -1091,10 +1091,10 @@ pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A,
 	        SUPERLU_FREE(R);
 		SUPERLU_FREE(C);
 		break;
-	    case ROW: 
+	    case ROW:
 		SUPERLU_FREE(C);
 		break;
-	    case COL: 
+	    case COL:
 		SUPERLU_FREE(R);
 		break;
 	}
